==> lmc-sdk-log4j2-1.1.2.0-sources.jar: com/digiwin/dap/middleware/lmc/internal/model/entity/DevLog.java <==
package com.digiwin.dap.middleware.lmc.internal.model.entity;

/**
 * 系统日志Entity
 *
 * @author chenzhuang
 * @date 2021/3/18 09:42
 */
public class DevLog extends BaseEntity {
    /** 应用Id */
    private String appId;
    /** 日志级别 */
    private String level;
    /** 时间 */
    private String time;
    /** 线程 */
    private String thread;
    /** 日志名称 */
    private String loggerName;
    /** 来源 */
    private String source;
    /** appender名称 */
    private String appender;
    /** 位置 */
    private String location;
    /** 租户id */
    private String tenantId;
    /** 租户name */
    private String tenantName;
    /** 日志信息 */
    private String message;
    /** 异常信息 */
    private String throwable;
    /** 完整log */
    private String log;

    /** 应用name */
    private String appName;

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }

    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    public String getThread() {
        return thread;
    }

    public void setThread(String thread) {
        this.thread = thread;
    }

    public String getLoggerName() {
        return loggerName;
    }

    public void setLoggerName(String loggerName) {
        this.loggerName = loggerName;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getAppender() {
        return appender;
    }

    public void setAppender(String appender) {
        this.appender = appender;
    }

    public String getLocation() {
        return location;
    }

    public void setLocation(String location) {
        this.location = location;
    }

    public String getTenantId() {
        return tenantId;
    }

    public void setTenantId(String tenantId) {
        this.tenantId = tenantId;
    }

    public String getTenantName() {
        return tenantName;
    }

    public void setTenantName(String tenantName) {
        this.tenantName = tenantName;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public String getThrowable() {
        return throwable;
    }

    public void setThrowable(String throwable) {
        this.throwable = throwable;
    }

    public String getLog() {
        return log;
    }

    public void setLog(String log) {
        this.log = log;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }
}

==> lmc-sdk-log4j2-3.0.0-20251204.033914-3-sources.jar: com/digiwin/dap/middleware/lmc/internal/model/entity/DevLog.java <==
package com.digiwin.dap.middleware.lmc.internal.model.entity;

/**
 * 系统日志Entity
 *
 * @author chenzhuang
 * @date 2021/3/18 09:42
 */
public class DevLog extends BaseEntity {
    /** 应用Id */
    private String appId;
    /** 日志级别 */
    private String level;
    /** 时间 */
    private String time;
    /** 线程 */
    private String thread;
    /** traceId */
    private String traceId;
    /** 日志名称 */
    private String loggerName;
    /** 来源 */
    private String source;
    /** appender名称 */
    private String appender;
    /** 位置 */
    private String location;
    /** 租户id */
    private String tenantId;
    /** 租户name */
    private String tenantName;
    /** 日志信息 */
    private String message;
    /** 异常信息 */
    private String throwable;
    /** 完整log */
    private String log;

    /** 应用name */
    private String appName;

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public String getLevel() {
        return level;
    }

    public void setLevel(String level) {
        this.level = level;
    }

    public String getTime() {
        return time;
    }

    public void setTime(String time) {
        this.time = time;
    }

    public String getThread() {
        return thread;
    }

    public void setThread(String thread) {
        this.thread = thread;
    }

    public String getTraceId() {
        return traceId;
    }

    public void setTraceId(String traceId) {
        this.traceId = traceId;
    }

    public String getLoggerName() {
        return loggerName;
    }

    public void setLoggerName(String loggerName) {
        this.loggerName = loggerName;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getAppender() {
        return appender;
    }

    public void setAppender(String appender) {
        this.appender = appender;
    }

    public String getLocation() {
        return location;
    }

    public void setLocation(String location) {
        this.location = location;
    }

    public String getTenantId() {
        return tenantId;
    }

    public void setTenantId(String tenantId) {
        this.tenantId = tenantId;
    }

    public String getTenantName() {
        return tenantName;
    }

    public void setTenantName(String tenantName) {
        this.tenantName = tenantName;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public String getThrowable() {
        return throwable;
    }

    public void setThrowable(String throwable) {
        this.throwable = throwable;
    }

    public String getLog() {
        return log;
    }

    public void setLog(String log) {
        this.log = log;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }
}
